@@ -4,6 +4,14 @@
 
 print.sarlm <- function(x, ...)
 {
+    .Deprecated("spatialreg::print.sarlm", msg="Method print.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+        return(spatialreg::print.sarlm(x=x, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 #FIXME
        if (x$type == "error") if (isTRUE(all.equal(x$lambda, x$interval[1])) ||
             isTRUE(all.equal(x$lambda, x$interval[2]))) 
@@ -20,10 +28,19 @@ print.sarlm <- function(x, ...)
 	cat("\nLog likelihood:", logLik(x), "\n")
 	invisible(x)
 }
+#}
 
 summary.sarlm <- function(object, correlation = FALSE, Nagelkerke=FALSE,
  Hausman=FALSE, adj.se=FALSE, ...)
 {
+    .Deprecated("spatialreg::summary.sarlm", msg="Method summary.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+        return(spatialreg::summary.sarlm(object, correlation = correlation, Nagelkerke=Nagelkerke, Hausman=Hausman, adj.se=adj.se, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 #FIXME
 	adj <- NULL
 	if (object$type == "error" || ((object$type == "lag" || 
@@ -107,17 +124,26 @@ summary.sarlm <- function(object, correlation = FALSE, Nagelkerke=FALSE,
 
 	structure(object, class=c("summary.sarlm", class(object)))
 }
-
+#}
+#if (FALSE) {
 NK.sarlm <- function(obj) {
      n <- length(residuals(obj))
      nullLL <- obj$LLNullLlm
      if (is.null(nullLL)) return(nullLL)
      c(1 - exp(-(2/n)*(logLik(obj) - nullLL)))
 }
-
+#}
 
 LR1.sarlm <- function(object)
 {
+    .Deprecated("spatialreg::LR1.sarlm", msg="Method LR1.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+    return(spatialreg::LR1.sarlm(object=object))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	if (!inherits(object, "sarlm")) stop("Not a sarlm object")
 	LLx <- logLik(object)
 #	LLy <- logLik(object$lm.model)
@@ -141,8 +167,17 @@ LR1.sarlm <- function(object)
 	class(res) <- "htest"
 	res
 }
+#}
 
 Wald1.sarlm <- function(object) {
+    .Deprecated("spatialreg::Wald1.sarlm", msg="Method Wald1.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::Wald1.sarlm(object=object))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	if (!inherits(object, "sarlm")) stop("Not a sarlm object")
 #	if (!object$ase) 
 #		stop("Cannot compute Wald statistic: parameter a.s.e. missing")
@@ -176,11 +211,20 @@ Wald1.sarlm <- function(object) {
 	res
 
 }
+#}
 
 Hausman.test <- function(object, ...)
     UseMethod("Hausman.test", object)
 
 Hausman.test.sarlm <- function(object, ..., tol=NULL) {
+    .Deprecated("spatialreg::Hausman.test.sarlm", msg="Method Hausman.test.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::Hausman.test.sarlm(object=object, ..., tol=tol))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     if (!inherits(object, "sarlm")) stop("not a sarlm object")
     if (object$type != "error") stop("not a spatial error model")
     fmeth <- ifelse(object$method != "eigen", "(approximate)", "(asymptotic)") 
@@ -209,8 +253,17 @@ Hausman.test.sarlm <- function(object, ..., tol=NULL) {
     class(res) <- "htest"
     res
 }
+#}
 
 Hausman.test.gmsar <- function(object, ..., tol=NULL) {
+    .Deprecated("spatialreg::Hausman.test.gmsar", msg="Method Hausman.test.gmsar moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::Hausman.test.gmsar(object=object, ..., tol=tol))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     if (!inherits(object, "gmsar")) stop("not a gmsar object")
     if (is.null(object$Hcov)) stop("Vo not available")
     fmeth <- "(approximate)"
@@ -238,10 +291,20 @@ Hausman.test.gmsar <- function(object, ..., tol=NULL) {
     class(res) <- "htest"
     res
 }
+#}
 
 print.summary.sarlm <- function(x, digits = max(5, .Options$digits - 3),
 	signif.stars = FALSE, ...)
 {
+    .Deprecated("spatialreg::print.summary.sarlm", msg="Method print.summary.sarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::print.summary.sarlm(x=x, digits = digits,
+	signif.stars = signif.stars, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	cat("\nCall:", deparse(x$call),	sep = "", fill=TRUE)
        if (x$type == "error") if (isTRUE(all.equal(x$lambda, x$interval[1])) ||
             isTRUE(all.equal(x$lambda, x$interval[2]))) 
@@ -402,3 +465,4 @@ print.summary.sarlm <- function(x, digits = max(5, .Options$digits - 3),
     	cat("\n")
         invisible(x)
 }
+#}
