@@ -174,47 +174,3 @@ out1 <- tm_shape(nc) + tm_fill(c("ft.SID74", "pred")) + tm_facets(free.scales=FA
 out2 <- tm_shape(nc) + tm_fill("mp_resid", midpoint=0) + tm_layout(legend.outside=TRUE)
 tmap_arrange(out1, out2, ncol=1)
 
-## ----echo=TRUE-----------------------------------------------------------
-sids.nhbr30.dist <- nbdists(ncCC89, cbind(nc$east, nc$north))
-sids.nhbr <- listw2sn(nb2listw(ncCC89, glist=sids.nhbr30.dist, style="B", zero.policy=TRUE))
-dij <- sids.nhbr[,3]
-n <- nc$BIR74
-el1 <- min(dij)/dij
-el2 <- sqrt(n[sids.nhbr$to]/n[sids.nhbr$from])
-sids.nhbr$weights <- el1*el2
-sids.nhbr.listw <- sn2listw(sids.nhbr)
-
-## ----echo=TRUE-----------------------------------------------------------
-nc$ft.NWBIR74 <- sqrt(1000)*(sqrt(nc$NWBIR74/nc$BIR74) + sqrt((nc$NWBIR74+1)/nc$BIR74))
-
-## ----echo=TRUE-----------------------------------------------------------
-lm_nc <- lm(ft.SID74 ~ 1, data=nc)
-outl <- which.max(rstandard(lm_nc))
-as.character(nc$NAME[outl])
-
-## ----echo=TRUE-----------------------------------------------------------
-W <- listw2mat(sids.nhbr.listw)
-W.4 <- W[-outl, -outl]
-sids.nhbr.listw.4 <- mat2listw(W.4)
-nc2 <- nc[!(1:length(nc$CNTY_ID) %in% outl),]
-
-## ----echo=TRUE-----------------------------------------------------------
-ecarIaw <- spautolm(ft.SID74 ~ 1, data=nc2, listw=sids.nhbr.listw.4, weights=BIR74, family="CAR")
-summary(ecarIaw)
-
-## ----echo=TRUE-----------------------------------------------------------
-ecarIIaw <- spautolm(ft.SID74 ~ both - 1, data=nc2, listw=sids.nhbr.listw.4, weights=BIR74, family="CAR")
-summary(ecarIIaw)
-
-## ----echo=TRUE-----------------------------------------------------------
-ecarIVaw <- spautolm(ft.SID74 ~ ft.NWBIR74, data=nc2, listw=sids.nhbr.listw.4, weights=BIR74, family="CAR")
-summary(ecarIVaw)
-
-## ---- eval=is_tmap, echo=TRUE--------------------------------------------
-nc2$fitIV <- fitted.values(ecarIVaw)
-tm_shape(nc2) + tm_fill("fitIV")
-
-## ----echo=TRUE-----------------------------------------------------------
-ecarIawll <- spautolm(ft.SID74 ~ 1, data=nc2, listw=sids.nhbr.listw.4, weights=BIR74, family="CAR", llprof=seq(-0.1, 0.9020532358, length.out=100))
-plot(ll ~ lambda, ecarIawll$llprof, type="l")
-
